@@ -10,7 +10,10 @@ class PowerGeneratingAsset(Asset):
 
 
 class RealEstateAsset(Asset):
-    pass
+    def __init__(self, latitude: float, longitude: float, *, location: str, type: str):
+        super().__init__(latitude, longitude)
+        self.location = location
+        self.type = type
 
 
 class TestAsset(Asset):
