@@ -1,8 +1,8 @@
-import collections
+import collections.abc
 
 
 def get_iterable(x):
-    if isinstance(x, collections.Iterable):
+    if isinstance(x, collections.abc.Iterable):
         return x
     else:
         return (x,)
